summaryrefslogtreecommitdiffstats
path: root/generic/tclTest.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tclTest.c')
-rw-r--r--generic/tclTest.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/generic/tclTest.c b/generic/tclTest.c
index a51f473..31deffe 100644
--- a/generic/tclTest.c
+++ b/generic/tclTest.c
@@ -4220,7 +4220,7 @@ TestsetplatformCmd(
* TeststaticpkgCmd --
*
* This procedure implements the "teststaticpkg" command.
* It is used to test the procedure Tcl_StaticPackage.
*
* Results:
* A standard Tcl result.
@@ -4252,7 +4252,7 @@ TeststaticpkgCmd(
if (Tcl_GetInt(interp, argv[3], &loaded) != TCL_OK) {
return TCL_ERROR;
}
- Tcl_StaticPackage((loaded) ? interp : NULL, argv[1],
+ Tcl_StaticLibrary((loaded) ? interp : NULL, argv[1],
StaticInitProc, (safe) ? StaticInitProc : NULL);
return TCL_OK;
}
@@ -4220,7 +4220,7 @@ TestsetplatformCmd(
*
* This procedure implements the "teststaticpkg" command.
- * It is used to test the procedure Tcl_StaticPackage.
+ * It is used to test the procedure Tcl_StaticLibrary.
*
* Results: